@@ -1,3 +1,5 @@
+from natch.abstract import Rule
+from natch.core.decoration import Decoration
 from natch.exceptions import NeverMatchesError
 from natch.decorators import any
 from natch.decorators import any_of
@@ -27,3 +29,41 @@ from natch.rules import NotContains
 from natch.rules import Condition
 from natch.rules import Partial
 from natch.rules import Pattern
+
+
+__version__ = '1.0.3'
+
+
+__all__ = [
+    'any',
+    'any_of',
+    'all_of',
+    'eq',
+    'neq',
+    'gt',
+    'gte',
+    'lt',
+    'lte',
+    'contains',
+    'not_contains',
+    'condition',
+    'partial',
+    'pattern',
+    'Any',
+    'AnyOf',
+    'AllOf',
+    'Eq',
+    'Neq',
+    'Gt',
+    'Gte',
+    'Lt',
+    'Lte',
+    'Contains',
+    'NotContains',
+    'Condition',
+    'Partial',
+    'Pattern',
+]
+
+
+make_rule_decorator = Decoration.make_rule_decorator
