@@ -1 +1,6 @@
 from natch.exceptions.never_matches_error import NeverMatchesError
+
+
+__all__ = [
+    'NeverMatchesError',
+]
